from aksharamukha import transliterate

import unittest

test_strings_rev = [
  ('អ អា អិ អី អុ អូ អេ អោ អៃ អៅ អំ អះ', '‛a ‛ā ‛i ‛ī ‛u ‛ū ‛e ‛o ‛ai ‛au ‛aṃ ‛aḥ'),
  ('អឹ អឺ អែ អៀ អឿ អើ', '‛ẏ ‛ȳ ‛ae ‛ia ‛ẏa ‛oe'),
  ('អ័ អ៍ អ៎ ខ័អ', '‛ă ‛a˚ ‛a’ khă‛ʹ'),
  ('ជ្អ ផ្អា ខ្អេ ជជ្អ', 'j‛a ph‛ā kh‛e jaj‛ʹ'),
  ('អ៊ អ៊ា អ៊ូ', '‛′a ‛′ā ‛′ū'),
  ('ឥ ឦ ឧ ឩ ឬ ឫ ឮ ឯ ឰ ឱ ឳ ឪ', 'i ī u ū ṝ ṛ ḹ ae ai o au ýu'),
  ('គ គា គិ គី គុ គូ គេ គៃ គោ គៅ កំ គះ', 'ga gā gi gī gu gū ge gai go gau kaṃ gaḥ'),
  ('កឹ គឺ គែ គៀ គឿ ឈើ', 'kẏ gȳ gae gia gẏa jhoe'),
  ('គ័ គ័ខ', 'gă găkh'),
  ('គគ៍ ខខ៎ ខខ៏ គ៍គ ខ៎ ខ៏ គខ៏ អ្នករ៉ូ', 'gag˚ khakh’ khakhʻ ga˚g kha’ khaʻ gakhʻ ‛ʹnakar″ū'),
  ('ជោះ', 'joaḥ'),
  ('អាឃ់ខ អៈឃ អខ់', '‛âghakh ‛àgh ‛ákh'),
  ('គ គខ ឋ៎ សទ្រ', 'ga gakh ṭha’ sadr'),
  ('ពឋ៎ឋ ពឋ៎ ឋ៎ព ឋ៎ឋ៎ ពឋ៏ឋ ពឋ៏ ឋ៏ព ឋ៏ឋ៏ ជក៌ឋ ជខ៌', 'baṭha’ṭh baṭh’ ṭha’b ṭha’ṭh’ baṭhaʻṭh baṭhʻ ṭhaʻb ṭhaʻṭhʻ jarkaṭh jarkh'),
  ('ទឆ៍ ឆឈ៎ វ៉វ៉', 'dach˚ chajh’ v″av″'),
  ('ឋវ៉ឋ ឋវ៉ ង៉ង៉ ង៉', 'ṭhav″aṭh ṭhav″ ṅ″aṅ″ ṅ″a'),
  ('ដល់ អធិបតេយ្យ', 'ṭál ‛adhipateyy'),
  ('ឆយ៍ តត់ កិក់ គគ់្ខ', 'chay˚ tát kík gágkh'),
  ('តត់ កិក់ សាគ់', 'tát kík sâg'),
  ('អាឃ់ខ អៈឃ អខ់', '‛âghakh ‛àgh ‛ákh'),
  ('ហអ្ន អ្នា ហខ្អ ហខ្អេ', 'ha‛ʹn ‛ʹnā hakh‛ʹ hakh‛e'),
  ('ក្រខ្វាក់ ក្សត្រិយ៍ សុី បុឹ អាត្ម័ន តត់ កាគ់', 'krakhvâk ksatriy˚ s′ī p″ẏ ‛ātmăn tát kâg')
]

test_strings_irrev = [
  ('តត់ កិក់ គគ់្ខ គក្ខ់ សាគ់', 'tát kík gágkh gákkh sâg'),
  ('៖ ៕ ។', ': . .'),
  ('ឲ្យ ឱ្យ', 'oy oy'),
  ('ឭ', 'ḷ')
]
class TestStringMethods(unittest.TestCase):
  def test_khmer_roman_loc(self):
    for khmer, loc in test_strings_rev + test_strings_irrev:
      self.assertEqual(transliterate.process('Khmer', 'RomanLoC', khmer), loc)

  def test_roman_loc_khmer(self):
    for khmer, loc in test_strings_rev:
      self.assertEqual(transliterate.process('RomanLoC', 'Khmer', loc), khmer)

if __name__ == '__main__':
  unittest.main()


# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\u1BC0',
            '\u1BC0\u02BD',
            '\u1BE4',
            '\u1BE4\u02BD',
            '\u1BE5',
            '\u1BE5\u02BD',
            'ᯒᯮ\u02BD',
            'ᯒᯮ\u02BD',
            'ᯞᯮ\u02BD',
            'ᯞᯮ\u02BD',
            '\u1BE4\u02BD',
            '\u1BC0\u1BE4\u02BD',
            '\u1BE5\u02BD',
            '\u1BC0\u1BE5\u02BD',
            ]

SouthVowelMap = [
                '\u1BE4\u02BD',
                '\u1BE5\u02BD',
                ]

ModernVowelMap = [
                 '\u1BE4\u02BD',
                 '\u1BC0\u02BD',
                 ]

SinhalaVowelMap = [
                  '\u1BE4\u02BD'
                  ]

VowelSignMap =  [
                '\u02BD\u02BD',
                '\u1BEA',
                '\u1BEA\u02BD',
                '\u1BEE',
                '\u1BEE\u02BD',
                'ᯒᯮ\u02BD',
                'ᯒᯮ\u02BD',
                'ᯞᯮ\u02BD',
                'ᯞᯮ\u02BD',
                '\u1BE9\u02BD',
                '\u1BE4\u02BD',
                '\u1BEC\u02BD',
                '\u1BE5\u02BD',
                ]

SouthVowelSignMap = [
                     '\u1BE9',
                     '\u1BEC',
                    ]

ModernVowelSignMap =[
                     '\u1BE9\u02BD',
                     '\u02BD\u02BD',
                    ]

SinhalaVowelSignMap = [
                      '\u1BE9\u02BD'
                      ]

AyogavahaMap = [
               '\u1BF0\u02BD',
               '\u1BF0',
               '\u1BC4\u1BF2\u02BD'
               ]

ViramaMap =  [
             '\u1BF2'
             ]

ConsonantMap =  [
                '\u1BC4\u1BE6',
                '\u1BC4\u1BE6\u02BD',
                '\u1BCE',
                '\u1BCE\u02BD',
                '\u1BDD',

                '\u1BDA\u1BE6',
                '\u1BDA\u1BE6\u02BD',
                '\u1BD0',
                '\u1BD0\u02BD',
                '\u1BE0',

                '\u1BD6\u02BD',
                '\u1BD6\u02BD',
                '\u1BD1\u02BD',
                '\u1BD1\u02BD',
                '\u1BCA\u02BD',

                '\u1BD6',
                '\u1BD6\u02BD',
                '\u1BD1',
                '\u1BD1\u02BD',
                '\u1BCA',

                '\u1BC7',
                '\u1BC7\u02BD',
                '\u1BC5',
                '\u1BC5\u02BD',
                '\u1BD4',

                '\u1BDB',
                '\u1BD2',
                '\u1BDE',
                '\u1BCD',

                '\u1BDA\u02BD',
                '\u1BDA\u02BD',
                '\u1BDA',
                '\u1BC4'
                ]

SouthConsonantMap = [
                    '\u1BDE\u02BD',
                    '\u1BDE\u02BD',
                    '\u1BD2\u02BD',
                    '\u1BCA\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\u1BC4\u1BE6\u02BD',
                     '\u1BC4\u1BE6\u02BD',
                     '\u1BCE\u02BD',
                     '\u1BD0\u02BD',
                     '\u1BD1\u02BD',
                     '\u1BD1\u02BD',
                     '\u1BC7\u02BD',
                     '\u1BDB\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\u1BF0\u1BCE\u02BD',
                     '\u1BF0\u1BD0\u02BD',
                     '\u1BF0\u1BD1\u02BD',
                     '\u1BF0\u1BD1\u02BD',
                     '\u1BF0\u1BC5\u02BD',
                      ]

NuktaMap = [
           '\u02BD\u02BD\u02BD\u02BD'
           ]

OmMap = [
        'ᯥᯔ᯲\u02BD'
        ]

SignMap =[
         "'",
         '\u002E',
         '\u002E'
         ]

Aytham =[AyogavahaMap[2]+'\u02BC']

NumeralMap = [
             '\u0030',
             '\u0031',
             '\u0032',
             '\u0033',
             '\u0034',
             '\u0035',
             '\u0036',
             '\u0037',
             '\u0038',
             '\u0039',
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])



# -*- coding: utf-8 -*-

# Script Mapping for ISO

VowelMap =  [
            'a',
            'A',
            'i',
            'I',
            'u',
            'U',
            'ru\u02BD',
            'rU\u02BD',
            'lu\u02BD',
            'lU\u02BD',
            'e',
            'ai',
            'o',
            'au'
            ]

SouthVowelMap = [
                'e\u02BD',
                'o\u02BD',
                ]

ModernVowelMap = [
                'e\u02BD',
                'A',
                 ]

SinhalaVowelMap = [
                'e\u02BD',
                  ]

VowelSignMap =  VowelMap[1:]

SouthVowelSignMap = SouthVowelMap[:]

ModernVowelSignMap = ModernVowelMap[:]

SinhalaVowelSignMap = SinhalaVowelMap[:]

AyogavahaMap = [
               'M\u02BD',
               'M',
               'h'
               ]

ViramaMap =  [
             '\u00D7'
             ]

ConsonantMap =  [
                'k',
                'K',
                'g',
                'G',
                '~',

                'c',
                'C',
                'j',
                'J',
                'Y',

                'T',
                'F',
                'D',
                'V',
                'N',

                't',
                'f',
                'd',
                '@',
                'n',

                'p',
                'P',
                'b',
                'B',
                'm',

                'y',
                'r',
                'l',
                'v',

                's\u02BD',
                's\u02BD',
                's',
                'h',
                ]

SouthConsonantMap = [
                    'L',
                    'L\u02BD',
                    'r\u02BD',
                    'n\u02BD'
                    ]

NuktaConsonantMap =  [
                     'k\u02BD',
                     'K\u02BD',
                     'g\u02BD',
                     'j\u02BD',
                    'D\u02BD',
                    'V\u02BD',
                     'P\u02BD',
                     'y\u02BD'
                     ]

SinhalaConsonantMap =[
                     'Mg\u02BD',
                     'Mj\u02BD',
                     'MD\u02BD',
                     'Md\u02BD',
                     'Mb\u02BD',
                      ]

NuktaMap = [
           '\u02BD\u02BD'
           ]

OmMap = [
        'oM'
        ]

SignMap =[
         '\u0027',
         '\u002E',
         '\u002E\u002E'
         ]

Aytham =['h\u02BD']

NumeralMap = [
             '\u0030',
             '\u0031',
             '\u0032',
             '\u0033',
             '\u0034',
             '\u0035',
             '\u0036',
             '\u0037',
             '\u0038',
             '\u0039',
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])


# -*- coding: utf-8 -*-

### Introduce Nasal to Anusvara for scripts lacking nasal letters but having Anusvara/Chandrabindu

import importlib, string
import re
from functools import reduce
from . import FallBack as fb

# Crunch Symbols

def ScriptPath(Script):
    if Script in MainIndic:
        return 'aksharamukha.ScriptMap.MainIndic.'+Script
    elif Script in EastIndic:
        return 'aksharamukha.ScriptMap.EastIndic.'+Script
    elif Script in Roman:
        return 'aksharamukha.ScriptMap.Roman.'+Script
    elif Script in NonIndic:
        return 'aksharamukha.ScriptMap.NonIndic.'+Script

def retCharList(charList):
    return globals()[charList]

def CrunchSymbols(Part,Script):
    ModScript = importlib.import_module(ScriptPath(Script))
    return reduce(lambda x,y : x+y,[getattr(ModScript,Var) for Var in Part])

def CrunchList(List,Script):
    try:
      ModScript = importlib.import_module(ScriptPath(Script))
    except:
      import logging
      logging.exception('The script ' + Script + ' cannot be found')
      return ''

    return getattr(ModScript,List)

#Introduce in all Latin Conversions
def EscapeChar(Strng):
    punct = "".join(['\\'+x for x in string.punctuation])

    return re.sub('('+punct+')',r'\\'+r'\1',Strng)


# Collection of Symbols

VedicSvaras = '('+ '|'.join(['᳚', '॑', '॒']) + ')?'
VedicSvarasList = ['᳚', '॑', '॒']

Vowels = ['VowelMap','SouthVowelMap','ModernVowelMap','SinhalaVowelMap']
VowelSignsNV = ['VowelSignMap','SouthVowelSignMap','ModernVowelSignMap','SinhalaVowelSignMap']
VowelSigns = ['ViramaMap','VowelSignMap','SouthVowelSignMap','ModernVowelSignMap','SinhalaVowelSignMap']
CombiningSigns = ['AyogavahaMap','NuktaMap']
Consonants = ['ConsonantMap','SouthConsonantMap','NuktaConsonantMap','SinhalaConsonantMap']

Signs = ['SignMap']
Numerals = ['NumeralMap']
Aytham =['Aytham']
om = ['OmMap']
virama = ['ViramaMap']

## Script Paths
MainIndic = ['GurmukhiLoC', 'LimbuLoC', 'BengaliRaBa', 'Nandinagari','Shahmukhi', 'TamilExtended','MasaramGondi','GunjalaGondi','Dogra', 'Ranjana', 'Khojki','GranthaGrantamil', 'Multani', 'Ahom', 'Mahajani','SiddhamDevanagari', 'Vatteluttu', 'GranthaPandya', 'Khudawadi', 'Bhaiksuki', 'Sharada', 'Newa', 'SylotiNagri', 'Takri', 'Tirhuta', 'Modi', 'Kaithi', 'Kharoshthi','Lepcha','Chakma','Brahmi','MeeteiMayek','Limbu','Assamese','Bengali','Devanagari','Grantha','Gujarati','Gurmukhi','Kannada','Malayalam','Oriya','Saurashtra','Sinhala','Tamil','TamilBrahmi','TamilGrantha','Telugu','Urdu']
EastIndic =['DivesAkuru', 'TibetanLoC', 'BatakLoC', 'ThamLoC', 'KhmerLoC', 'ShanLoC', 'Makasar', 'Kawi', 'Pallava', 'LaoTham', 'LueTham', 'KhuenTham', 'Marchen', 'Soyombo', 'KhomThai', 'KhamtiShan', 'TaiLaing', 'Mon', 'Shan', 'ZanabazarSquare','Rejang', 'Lao2','Buhid', 'Hanunoo', 'Siddham', 'Tibetan','Lao','TaiTham','Cham','BatakKaro','BatakPakpak','BatakSima','BatakToba','BatakManda','LaoPali','PhagsPa','Buginese','Tagbanwa','Tagalog','Sundanese','Balinese','Burmese','Javanese','Khmer','Siddham','Ranjana','Thaana','Thai', 'BurmeseALALC']
NonIndic = ['OldPersian', 'Hebrew']
Roman =['BatakLoCRomanLoC','GurmukhiLoCRomanLoC','TibetanLoCRomanLoC', 'LimbuLoCRomanLoC', 'BalineseSimpleRomanLoC', 'BalineseRomanLoC', 'JavaneseSimpleRomanLoC', 'JavaneseRomanLoC', 'BatakKaroRomanLoC', 'BatakMandaRomanLoC','BatakPakpakRomanLoC','BatakSimaRomanLoC','BatakTobaRomanLoC', 'GurmukhiRomanLoC', 'TibetanRomanLoC', 'LimbuRomanLoC', 'KannadaRomanLoC', 'TeluguRomanLoC', 'SinhalaRomanLoC', 'OriyaRomanLoC', 'AssameseRomanLoC', 'BengaliRomanLoC', 'GujaratiRomanLoC', 'DevanagariRomanLoC', 'ThamLoCRomanLoC', 'KhmerLoCRomanLoC', 'RomanLoC', 'ShanLoCRomanLoC', 'ThamLoCRomanLoC', 'KhmerLoCRomanLoC', 'ShanLoCRomanLoC', 'BurmeseRomanLoC', 'RomanSemitic', 'RomanColloquial', 'ISOPali', 'RomanKana', 'BarahaNorth', 'BarahaSouth', 'Mongolian', 'SLP1', 'Wancho', 'Mro', 'IASTPali', 'HanifiRohingya', 'Ariyaka', 'RomanReadable', 'Aksharaa', 'WarangCiti', 'SoraSompeng',"WX-kok",'Avestan','HK','IAST','ISO','Itrans','Titus','Titus','Velthuis','WX','Inter','IPA','TolongSiki','Santali','RussianCyrillic']
RomanDiacritic = ['IAST','Titus','ISO','IPA', 'IASTPali', 'ISOPali', 'BurmeseRomanLoC', 'ISOLOC', 'RomanSemitic', 'ShanLoCRomanLoC', 'KhmerLoCRomanLoC']

ScriptCategory = {}

ScriptCategory['IndianMain'] = ['GranthaGrantamil','Assamese','Bengali','Devanagari','Gujarati','Gurmukhi','Kannada','Malayalam','Oriya','Sinhala','Tamil','Telugu','Urdu']
ScriptCategory['IndianMinority'] = ['Brahmi','Chakma','Grantha','Lepcha','Limbu','MeeteiMayek','Saurashtra','TamilBrahmi','TamilGrantha', 'Kaithi']
ScriptCategory['EastAsianPaliSans'] = ['Balinese','Burmese','Cham','Javanese','Khmer','LaoPali','Lao','PhagsPa','TaiTham','Thaana','Thai','Tibetan']
ScriptCategory['EastAsianIndFili'] = ['BatakKaro','BatakManda','BatakPakpak','BatakSima','BatakToba','Buginese','Sundanese','Tagalog','Tagbanwa']
ScriptCategory['IndianAlpha'] = ['Santali','TolongSiki']
ScriptCategory['RomanDiacritic'] = ['IAST','IPA','ISO','Titus', 'IASTPali']
ScriptCategory['RomanNonDiacritic'] = ['HK','Itrans','RussianCyrillic','Velthuis','WX']
ScriptCategory['NonIndic'] = ['Avestan','OldPersian']

Inter = "Inter"

Characters = Vowels + VowelSigns + CombiningSigns + Consonants
CharactersNV = Vowels + VowelSignsNV + CombiningSigns + Consonants

Diacritics = ['ʽ', '\u00B7', '\u00B9','\u00B2','\u00B3','\u2074','\u2081','\u2082','\u2083','\u2084']
DiacriticsRemovable = ['ʼ', 'ˇ', 'ˆ', '˘', '\u00B7']
DiacriticsRemovableTamil = ['ˇ', 'ˆ', '˘', '\u00B7']

ScriptAll = ['Aytham', 'Signs', 'CombiningSigns', 'VowelSigns', 'Vowels', 'Consonants', 'Numerals']

IndicScripts = [
               'DivesAkuru',
               'TibetanLoC',
               #'BatakLoC',
               'GurmukhiLoC',
               'LimbuLoC',
               'ThamLoC',
               'KhmerLoC',
               'ShanLoC',
               'BengaliRaBa',
               'RomanSemitic',
                'Makasar',
                'Nandinagari',
                'Kawi',
                'Shahmukhi',
                'Pallava',
                'Hebrew',
               'LaoTham',
               'LueTham',
               'KhuenTham',
               'TamilExtended',
               'Marchen',
               'MasaramGondi',
               'GunjalaGondi',
               'Soyombo',
               'Dogra',
               'KhomThai',
               'KhamtiShan',
               'TaiLaing',
               'Mon',
               'Khojki',
               'Shan',
               'Ranjana',
               'ZanabazarSquare',
               'Rejang',
               'GranthaGrantamil',
               'Devanagari',
               'Multani',
               'Ahom',
               'Mahajani',
               'Lao2',
               'Hanunoo',
               'Buhid',
               'Siddham',
               'SiddhamDevanagari',
               'GranthaPandya',
               'Vatteluttu',
               'Khudawadi',
               'Bhaiksuki',
               'Sharada',
               'Newa',
               'Takri',
               'SylotiNagri',
               'Tirhuta',
               'Modi',
               'Kaithi',
               'Kharoshthi',
               'Telugu',
               'Kannada',
               'Malayalam',
               'Gujarati',
               'Bengali',
               'Oriya',
               'Gurmukhi',
               'Tamil',
               'Assamese',
               'Saurashtra',
               'TamilBrahmi',
               'Grantha',
               'TamilGrantha',
               'Sinhala',
               'Khmer',
               'Burmese',
               'Urdu',
               'Balinese',
               'Javanese',
               'Thaana',
               'Tibetan',
               'Thai',
               'OldPersian',
               'Limbu',
               'Lepcha',
               'Sundanese',
               'Tagalog',
               'Tagbanwa',
               'Buginese',
               'Chakma',
               'PhagsPa',
               'MeeteiMayek',
               'LaoPali',
               'BatakKaro','BatakPakpak','BatakSima','BatakToba','BatakManda',
               'Cham',
               'TaiTham',
               'Lao',
               'Brahmi'
               ]

SiddhamRanjana = ['Ranjana']

LatinScripts = [#'BatakLoCRomanLoC', 'BatakKaroRomanLoC', 'BatakMandaRomanLoC','BatakPakpakRomanLoC','BatakSimaRomanLoC','BatakTobaRomanLoC', 'GurmukhiRomanLoC' \
                'GurmukhiLoCRomanLoC', 'TibetanLoCRomanLoC', 'LimbuLoCRomanLoC', 'BalineseSimpleRomanLoC', 'BalineseRomanLoC', 'JavaneseSimpleRomanLoC', 'JavaneseRomanLoC', 'KannadaRomanLoC', 'TeluguRomanLoC', 'SinhalaRomanLoC', 'OriyaRomanLoC', 'AssameseRomanLoC', 'BengaliRomanLoC', 'GujaratiRomanLoC', 'DevanagariRomanLoC', 'ThamLoCRomanLoC', 'KhmerLoCRomanLoC', 'RomanLoC', 'ShanLoCRomanLoC', 'BurmeseRomanLoC', 'RomanColloquial', 'ISOPali', 'RomanKana', 'BarahaNorth', 'BarahaSouth', 'Mongolian', 'SLP1', 'Wancho', 'Mro', 'IASTPali', 'HanifiRohingya','Ariyaka', 'RomanReadable', 'Aksharaa', 'WarangCiti', 'SoraSompeng','WX-kok','Avestan','ISO','IAST','HK','Titus','Itrans','Velthuis','WX','Inter','IPA','TolongSiki','Santali','RussianCyrillic']

Gemination =  {
               'Gurmukhi' : '\u0A71',
               'Thaana' : '\u0787\u07B0',
               'Urdu': '\u0651',
               'Shahmukhi': '\u0651',
               'Grantha': '𑌂',
               'Malayalam': 'ം',
               'Khojki': '\U00011237',
               'Buginese': '',
               'Buhid': '',
               'Tagbanwa': '',
               'Makasar': ''
              }

pipeScripts = ["HK", "IASTPali", "IAST", "ISO", "Itrans", "ISOPali"]

Transliteration = ['IASTPali', 'RomanReadable', 'Aksharaa', 'ISO', 'IAST', 'HK','Titus','Itrans','Velthuis', 'WX', 'IPA', 'RussianCyrillic', 'IASTPali', 'ISOPali', 'RomanLoC']

## Indic scripts that use roman numerals
romanNumeralScripts = ['Tamil', 'Gurmukhi', 'Malayalam', 'Telugu']
## Indic scripts that use periods
romanPunctscripts = ['Tamil', 'Kannada', 'Malayalam', 'Telugu', 'Gujarati']

## List of supported LoC scripts
LoCScripts = ['Burmese', 'Shan', 'Khmer', 'KhuenTham', 'TaiTham', 'LaoTham', 'LueTham', 'Kannada', 'Tamil', 'Malayalam', 'Sinhala', 'Telugu', 'Kannada', 'Oriya', 'Assamese', 'Bengali', 'Gujarati', 'Devanagari', 'Balinese', 'Javanese', 'BatakKaro', 'BatakManda','BatakPakpak','BatakSima','BatakToba','Gurmukhi', 'Tibetan', 'Limbu']

#Modified Src Input Map for LoC script
#speicalpostpre process
LocPostPre = ['Burmese', 'Shan', 'Khmer', 'ThamLoC', 'ShanLoC', 'KhmerLoC']
#spcial Loc source
LoCSrcMap =  ['Shan', 'Khmer', 'Gurmukhi', 'Limbu', 'Tibetan']
#Sepcial Map for RomanLoC target
LoCTgtMap = ['Burmese', 'Shan', 'Khmer', 'KhuenTham', 'TaiTham', 'LaoTham', 'LueTham', 'ThamLoC', 'ShanLoC', 'KhmerLoC', 'Kannada', 'Telugu', 'Sinhala', 'Oriya', 'Assamese', 'Bengali', 'Gujarati', 'Devanagari', 'Balinese', 'Javanese', 'Batak', 'Gurmukhi', 'GurmukhiLoC', 'Tibetan', 'Limbu', 'LimbuLoC', 'Tibetan', 'TibetanLoC']

#They're basically modified ISO
LoCTgtISO = ['Tamil', 'Malayalam']

##
LoCTgtPostOptions = {
    'Telugu': ['AnusvaratoNasalASTISO', 'RomanLoCChandrabindu'],
    'Kannada': ['AnusvaratoNasalASTISO', 'RomanLoCChandrabindu'],
    'Malayalam': ['AnusvaratoNasalASTISO', 'RomanLoCChandrabindu', 'MalayalamRomanLoCFix', 'mDotBelowToAbove'],
    'Sinhala': ['AnusvaratoNasalASTISO',  'SinhalaSannakaNasalization', 'RomanLoCChandrabindu'],
    'Oriya': ['AnusvaratoNasalASTISO', 'RomanLoCChandrabindu'],
    'Assamese': ['RomanLoCChandrabindu'],
    'GurmukhiLoC': ['GurmukhiRomanLoCFix'],
    'Bengali': ['RomanLoCChandrabindu'],
    'Gujarati': ['AnusvaratoNasalASTISO', 'RomanLoCChandrabindu'],
    'Devanagari': ['AnusvaratoNasalASTISO', 'RomanLoCChandrabindu', 'DevanagariRomanLoCFix'],
    'Balinese': ['BalineseRomanLoCFix'],
    'Javanese': ['JavaneseRomanLoCFix'],
    'TibetanLoC': ['TibetanLoCRomanLoCFix']
}

##
LoCTgtPreOptions = {
    'Assamese': ['KhandaTaRomanLoC'],
    'Bengali': ['KhandaTaRomanLoC', 'BengaliSubojinedVa'],
}

##
LoCSrcPostOptions = {
    'Assamese': ['KhandaTaRomanLoC'],
    'Bengali': ['KhandaTaRomanLoC'],
    'Telugu':['TeluguArasunnaChandrabindu']
}

##
LoCSrcPreOptions = {
    'Telugu': ['RomanLoCChandrabindu'],
    'Kannada': ['RomanLoCChandrabindu'],
    'Malayalam': ['RomanLoCChandrabindu', 'MalayalamRomanLoCFix'],
    'Sinhala': ['RomanLoCChandrabindu'],
    'Oriya': ['RomanLoCChandrabindu'],
    'Assamese': ['RomanLoCChandrabindu'],
    'Bengali': ['RomanLoCChandrabindu'],
    'Gujarati': [ 'RomanLoCChandrabindu'],
    'Devanagari': ['RomanLoCChandrabindu', 'DevanagariRomanLoCFix'],
    'Balinese': ['BalineseRomanLoCFix'],
    'Javanese': ['JavaneseRomanLoCFix'],
    'TibetanLoC': ['TibetanLoCRomanLoCFix']
}

SemiticScripts = ['Arab-Pa', 'Syrj', 'Syrn', 'Syre', 'Thaa', 'Arab-Ur', 'Type', 'Hebr-Ar', 'Arab-Fa', 'Latn', 'Arab', 'Ethi', 'Armi', 'Brah', 'Chrs', 'Egyp', 'Elym', 'Grek', 'Hatr', 'Hebr', 'Mani', 'Narb', 'Nbat', 'Palm', 'Phli', 'Phlp', 'Phnx', 'Prti', 'Samr', 'Sarb', 'Sogd', 'Sogo', 'Ugar']

## Add new consonants here

SemiticConsonants = ['ʾ','b','v','g','j','d','h','w','z','ḥ','ṭ','y','k','l','m','n','s','ʿ','f','ṣ','q','r','š','t','ḍ','ḏ','ḫ','ġ','ṯ','ẓ','p','č','ž','ɖ','ʈ','ʂ','ɭ','ɲ','ɳ','ɽ','ʰ'] # make a list

SemiticVowels = ['a', 'ā', 'i', 'ī', 'u', 'ū', 'ē', 'ō', 'e', 'o', '#', '\u033D']

semiticVowelsAll = '꞉ a ā i ī u ū e ē o ō a̮ ̽ ā̮ ĕ ă ŏ aŷ aŵ a aⁿ uⁿ iⁿ'.split(' ')
vowelsInitialAll = 'ˀā̮̂ ā̮̂ â ā̂ î ī̂ û ū̂ ê ē̂ ô ō̂ âŷ âŵ ˀâ ˀî'.split(' ')

semiticISO = {
                'ISO259': 'Hebrew',
                'HebrewSBL': 'Hebrew',
                'ISO233': 'Arab',
                'PersianDMG': 'Arab-Fa'
}

ReversibleScripts = ['Devanagari', 'Tamil', 'Telugu', 'Kannada', 'Sinhala', 'Oriya', 'Gujarati', 'Bengali', 'Assamese', 'Malayalam', 'Gurmukhi']

RomanReversible = ['IAST', 'HK', 'Itrans', 'Velthuis', 'Titus', 'WX', 'RussianCyrillic', 'ISO']

CharmapLists = ['VowelMap', 'VowelSignMap', 'ConsonantMap', 'SignMap', 'AyogavahaMap', 'ModernVowelMap', 'ModernVowelSignMap']
InterAdd = {'VowelMap': '\U000F0000', 'VowelSignMap': '\U000F0000', 'ConsonantMap':'\U000F2000', 'SignMap':'\U000F3000', 'AyogavahaMap':'\U000F4000', 'ModernVowelMap': '\U000F5000', 'ModernVowelSignMap':'\U000F5000'}

def add_additional_chars(script_char_map, file_script):
    for charlist in CharmapLists:
        mapping_char = getattr(fb, charlist)
        #print('vinodh')
        #print(file_script)
        ModScript = importlib.import_module(ScriptPath(file_script))
        InterAddIndex = ord(InterAdd[charlist])
        for num, mapng in enumerate(mapping_char.items()):
                char, mapping = mapng
                if file_script in mapping.keys():
                        script_char_map[charlist].append(mapping[file_script])
                elif file_script == 'Inter':
                        script_char_map[charlist].append(chr(InterAddIndex+num))
                else:
                    if file_script in ReversibleScripts:
                        mapchar = 'OthersRev'
                    else:
                        mapchar = 'OthersNonRev'

                    if mapping[mapchar][0] == -1:
                         first_char = ''
                    else:
                         #print(charlist)
                         #print(mapping[mapchar][0])
                         first_char= script_char_map[charlist][mapping[mapchar][0]]

                    if len(mapping[mapchar]) > 1:
                        if 'nukta' in mapping[mapchar]:
                            second_char = ModScript.NuktaMap[0]
                        else:
                            second_char = mapping[mapchar][1]

                    if len(mapping[mapchar]) == 1:
                        script_char_map[charlist].append(first_char)
                    else:
                        script_char_map[charlist].append(first_char+second_char)




# -*- coding: utf-8 -*-

# http://www.nguoicham.com/document/35/akhar-thrah-7-harei-học-chữ-cham-quot-akhar-thrah-quot-trong-7-ngày/

# Script Mapping for Devanagari

VowelMap =  [
            '\uAA00',
            '\uAA00\uAA29',
            '\uAA01',
            '\uAA01\uAA29',
            '\uAA02',
            '\uAA02\uAA29',
            '\uAA23\uAA2E',
            '\uAA23\uAA2E\uAA29',
            '\uAA24\uAA2E',
            '\uAA24\uAA2E\uAA29',
            '\uAA03',
            '\uAA04',
            '\uAA05',
            '\uAA00\uAA2F\uAA31',
            ]

SouthVowelMap = [
                '\uAA03\u02BD',
                '\uAA05\u02BD',
                ]

ModernVowelMap = [
                 '\uAA03\u02BD',
                 '\uAA00\uAA29\u02BD',
                 ]

SinhalaVowelMap = [
                  '\uAA03\u02BD'
                  ]

VowelSignMap =  [
                '\uAA29',
                '\uAA2A',
                '\uAA2B',
                '\uAA2D',
                '\uAA2D\uAA29',
                '\u02BE\uAA23\uAA2E',
                '\u02BE\uAA23\uAA2E\uAA29',
                '\u02BE\uAA24\uAA2E',
                '\u02BE\uAA24\uAA2E\uAA29',
                '\uAA2F\uAA2E',
                '\uAA30',
                '\uAA2F',
                '\uAA2F\uAA31',
                ]

SouthVowelSignMap = [
                    '\uAA2F\uAA2E\u02BD',
                    '\uAA2E\u02BD',
                    ]

ModernVowelSignMap =[
                    '\uAA2F\uAA2E\u02BD',
                    '\uAA29\u02BD']

SinhalaVowelSignMap = [
                    '\uAA2F\uAA2E\u02BD',
                      ]

AyogavahaMap = [
               '\uAA43',
               '\uAA4C',
               '\uAA4D'
               ]

ViramaMap =  [
             '\u02BE'
             ]

ConsonantMap =  [
                '\uAA06',
                '\uAA07',
                '\uAA08',
                '\uAA09',
                '\uAA0B',

                '\uAA0C',
                '\uAA0D',
                '\uAA0E',
                '\uAA0F',
                '\uAA11',

                '\uAA13\u02BD',
                '\uAA14\u02BD',
                '\uAA15\u02BD',
                '\uAA16\u02BD',
                '\uAA18\u02BD',

                '\uAA13',
                '\uAA14',
                '\uAA15',
                '\uAA16',
                '\uAA18',

                '\uAA1A',
                '\uAA1C',
                '\uAA1D',
                '\uAA1E',
                '\uAA20',

                '\uAA22',
                '\uAA23',
                '\uAA24',
                '\uAA25',

                '\uAA26\u02BD',
                '\uAA26',
                '\uAA27',
                '\uAA28'
                ]

SouthConsonantMap = [
                    '\uAA24\u02BD',
                    '\uAA24\u02BD',
                    '\uAA23\u02BD',
                    '\uAA18\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\uAA06\u02BD',
                     '\uAA07\u02BD',
                     '\uAA08\u02BD',
                     '\uAA0E\u02BD',
                     '\uAA15\u02BD',
                     '\uAA16\u02BD',
                     '\uAA1C\u02BD',
                     '\uAA25\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\uAA4C\uAA08\u02BD',
                     '\uAA12',
                     '\uAA19\u02BD',
                     '\uAA19',
                     '\uAA21',
                      ]

NuktaMap = [
           '\u02BD\u02BD\u02BD\u02BD'
           ]

OmMap = [
        '\uAA05\uAA4C'
        ]

SignMap =[
         "'",
         '\uAA5D',
         '\uAA5E'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']


NumeralMap = [
             '\uAA50',
             '\uAA51',
             '\uAA52',
             '\uAA53',
             '\uAA54',
             '\uAA55',
             '\uAA56',
             '\uAA57',
             '\uAA58',
             '\uAA59',
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])



# -*- coding: utf-8 -*-

# Script Mapping for ISO

VowelMap =  [
            'ᠠ᠋',
            'ᠠ᠋᠎ᠠ',
            '\u1888',
            'ᠢᠢ',
            'ᠦ',
            'ᠤᠦ',
            'ᠷᠢ',
            'ᠷᠢᠢ',
            'ᠯᠢ',
            'ᠯᠢᠢ',
            'ᠧ',
            'ᠧ\u02BCᠧ',
            'ᠣᠸᠠ',
            'ᠣᠸᠸᠠ'
            ]

SouthVowelMap = [
                'ᠧ\u02BD',
                'ᠣᠸᠠ\u02BD',
                ]

ModernVowelMap = [
                'ᠣᠸᠠ\u02BD',
                'ᠠ\u02BD',
                 ]

SinhalaVowelMap = [
                'ᠣᠸᠠ\u02BD',
                  ]

VowelSignMap =  VowelMap[1:]

SouthVowelSignMap = SouthVowelMap[:]

ModernVowelSignMap = ModernVowelMap[:]

SinhalaVowelSignMap = SinhalaVowelMap[:]

AyogavahaMap = [
               '\u1880\u02BD',
               '\u1880',
               '\u1881'
               ]

ViramaMap =  [
             '\u00D7'
             ]

ConsonantMap =  [
                'ᢉ',
                'ᠻ',
                'ᠺ',
                'ᠺᠾ',
                'ᢊ',

                'ᢋ',
                'ᠼ',
                'ᢖ',
                'ᢖᠾ',
                'ᡛ',

                'ᢌ',
                'ᢍ',
                'ᢎ',
                'ᢎᠾ',
                'ᢏ',

                'ᢐ',
                'ᠲ',
                'ᢑ',
                'ᢑᠾ',
                'ᠨ',

                'ᢒ',
                'ᠹ',
                'ᠪ',
                'ᠪᠾ',
                'ᠮ',

                'ᠶ',
                'ᠷ',
                'ᠯ',
                'ᠸ',

                'ᠱ',
                'ᢔ',
                'ᠰ',
                'ᡙ',
                ]

SouthConsonantMap = [
                    'ᠯ\u02BD',
                    'ᠯ\u02BD',
                    'ᠷ\u02BD',
                    'ᠨ\u02BD'
                    ]

NuktaConsonantMap =  [
                    'ᢉ\u02BD',
                    'ᠻ\u02BD',
                    'ᠺ\u02BD',
                    '\u1896',
                'ᢎ\u02BD',
                'ᢎᠾ\u02BD',
                'ᠹ\u02BD',
                'ᠶ\u02BD',
                     ]

SinhalaConsonantMap =[
                     '\u1880ᠺ\u02BD',
                     '\u1880ᢖ\u02BD',
                     '\u1880ᢎ\u02BD',
                     '\u1880ᢑ\u02BD',
                     '\u1880ᠪ\u02BD',
                      ]

NuktaMap = [
           '\u02BD\u02BD'
           ]

OmMap = [
        'ᢀᠣᠸᠠ'
        ]

SignMap =[
         '\u02BD\u02BD\u02BD',
         '\u1802',
         '\u1802\u1802'
         ]

Aytham =['\u1881\u02BD']

NumeralMap = [
             '\u1810',
             '\u1811',
             '\u1812',
             '\u1813',
             '\u1814',
             '\u1815',
             '\u1816',
             '\u1817',
             '\u1818',
             '\u1819',
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])


# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '𑀅',
            '𑀆',
            '𑀇',
            '𑀈',
            '𑀉',
            '𑀊',
            '𑀋',
            '𑀌',
            '𑀍',
            '𑀎',
            '𑀏',
            '𑀐',
            '𑀑',
            '𑀒',
            ]

SouthVowelMap = [
                '𑀏\u02BD',
                '𑀑\u02BD',
                ]

ModernVowelMap = [
                 '𑀏\u02BD',
                 '𑀆\u02BD',
                 ]

SinhalaVowelMap = [
                  '𑀏\u02BD'
                  ]

VowelSignMap =  [
                '𑀸',
                '𑀺',
                '𑀻',
                '𑀼',
                '𑀽',
                '𑀾',
                '𑀿',
                '𑁀',
                '𑁁',
                '𑁂',
                '𑁃',
                '𑁄',
                '𑁅',
                ]

SouthVowelSignMap = [
                    '𑁂\u02BD',
                    '𑁄\u02BD',
                    ]

ModernVowelSignMap =[
                    '𑁂\u02BD',
                    '𑀸\u02BD']

SinhalaVowelSignMap = [
                      '𑁂\u02BD'
                      ]

AyogavahaMap = [
               '𑀀',
               '𑀁',
               '𑀂'
               ]

ViramaMap =  [
             '𑁆'
             ]

ConsonantMap =  [
                '𑀓',
                '𑀔',
                '𑀕',
                '𑀖',
                '𑀗',

                '𑀘',
                '𑀙',
                '𑀚',
                '𑀛',
                '𑀜',

                '𑀝',
                '𑀞',
                '𑀟',
                '𑀠',
                '𑀡',

                '𑀢',
                '𑀣',
                '𑀤',
                '𑀥',
                '𑀦',

                '𑀧',
                '𑀨',
                '𑀩',
                '𑀪',
                '𑀫',

                '𑀬',
                '𑀭',
                '𑀮',
                '𑀯',

                '𑀰',
                '𑀱',
                '𑀲',
                '𑀳'
                ]

SouthConsonantMap = [
                    '𑀴',
                    '𑀴\u02BD',
                    '𑀭\u02BD',
                    '𑀦\u02BD'
                    ]

NuktaConsonantMap =  [
                    '𑀓\u02BD',
                    '𑀔\u02BD',
                    '𑀕\u02BD',
                    '𑀚\u02BD',
                    '𑀟\u02BD',
                    '𑀠\u02BD',
                    '𑀨\u02BD',
                    '𑀬\u02BD'
                     ]

SinhalaConsonantMap =[
                     '𑀀𑀕\u02BD',
                     '𑀀𑀚\u02BD',
                     '𑀀𑀟\u02BD',
                     '𑀀𑀤\u02BD',
                     '𑀀𑀩\u02BD',
                      ]

NuktaMap = [
           '\u02BD\u02BD\u02BD\u02BD'
           ]

OmMap = [
        '𑀑𑀁'
        ]

SignMap =[
         '\u02BD\u02BD',
         '𑁇',
         '𑁈'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']

NumeralMap = [
             '𑁦',
             '𑁧',
             '𑁨',
             '𑁩',
             '𑁪',
             '𑁫',
             '𑁬',
             '𑁭',
             '𑁮',
             '𑁯',
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])



# -1 means don't use internal mapping - just use there replacement character
# nuk means use nukta with replacement character
# [1, "x"] combine the index 1 of the list with x

## OthersRev will always two values:
 # base characters + 'an addition'
## OtherNonREv
 # Singlechar - \u02BC will be added automatically to make it not reversible

## if first is nukta
 # Nukta will be added

VowelMap = {
'halfu': {
    'Malayalam': 'ഉ\u0D4D',
    'Devanagari': 'ॶ',
    'Sharada': '𑆃𑇋𑆶',
    'Tamil': 'உ\u0BCD',
    'IAST': 'ŭ',
    'ISO': 'ŭ',
    'IPA': 'ʉ',
    'OthersRev': [4, 'ʼ'],
    'OthersNonRev': [4, '\u02C2']
    },
'halfuu': {
    'Malayalam': 'ഊ\u0D4D',
    'Devanagari': 'ॷ',
    'Sharada': '𑆃𑇋𑆷',
    'Tamil': 'ஊ\u0BCD',
    'IAST': 'ŭ\u0304',
    'ISO': 'ŭ\u0304',
    'IPA': 'ʉː',
    'OthersRev': [5, 'ʼ'],
    'OthersNonRev': [5, '\u02C2']
    },
'oe': {
    'Devanagari': 'ॳ',
    'Sharada': '𑆃𑇋',
    'IAST': 'ö',
    'ISO': 'ö',
    'IPA': 'ʉː',
    'OthersRev': [1, 'ʼʼ'],
    'OthersNonRev': [1, '\u02C2']
    },
'oee': {
    'Devanagari': 'ॴ',
    'Sharada': '𑆃𑇋𑆳',
    'IAST': 'ȫ',
    'ISO': 'ȫ',
    'IPA': 'ʉː',
    'OthersRev': [1, 'ʼʼʼ'],
    'OthersNonRev': [1, '\u02C2']
    },
'ShanLoCesup': {
        'ShanLoC': 'ဢဵ',
        'Shan': 'ဢဵ',
        'ShanLoCRomanLoC': 'e\u02BD',
        'OthersRev': [10, '\u02C2'],
        'OthersNonRev': [10, '\u02C2'],
    },
'ShanLoCui': {
       'ShanLoC': 'ဢို',
       'Shan': 'ဢို',
       'ShanLoCRomanLoC': 'ui',
       'OthersRev': [4, '\u02C2'],
       'OthersNonRev': [4, '\u02C2'],
    },
'ShanLoCuui': {
       'ShanLoC': 'ဢိူ',
       'Shan': 'ဢိူ',
       'ShanLoCRomanLoC': 'ūi',
       'OthersRev': [5, '\u02C2'],
       'OthersNonRev': [5, '\u02C2'],
    },
'ShanLoCuuiv': {
       'ShanLoC': 'ဢိူဝ်',
       'Shan': 'ဢိူဝ်',
       'ShanLoCRomanLoC': 'ūiv',
       'OthersRev': [5, '\u02C2'],
       'OthersNonRev': [5, '\u02C2'],
    },
'ShanLoCaai': {
       'ShanLoC': 'ဢၢႆ',
       'Shan': 'ဢၢႆ',
       'ShanLoCRomanLoC': 'āi',
       'OthersRev': [11, '\u02C2'],
       'OthersNonRev': [11, '\u02C2'],
    },
'ShanLoCaoi': {
       'ShanLoC': 'ဢွႆ',
       'Shan': 'ဢွႆ',
       'ThamLoC': 'ᩋ\u1A7Fᩅᩭ',
       'ShanLoCRomanLoC': 'oi',
       'ThamLoCRomanLoC': 'oi',
       'OthersRev': [11, '\u02C2'],
       'OthersNonRev': [11, '\u02C2'],
    },
'ShanLoCoalt1': {
       'ShanLoC': 'ဢေႃ်',
       'Shan': 'ဢေႃ်',
       'ShanLoCRomanLoC': 'ò',
       'OthersRev': [12, '\u02C2'],
       'OthersNonRev': [12, '\u02C2'],
    },
 'ShanLoCoalt': {
     'ShanLoC': 'ဢူဝ်',
     'Shan': 'ဢူဝ်',
     'ShanLoCRomanLoC': 'ō',
     'OthersRev': [12, '\u02C2'],
     'OthersNonRev': [12, '\u02C2'],
    },
 'ShanLoCaialt': {
     'ShanLoC': 'ဢ\u036E',
     'Shan': 'ဢ\u036E',
     'ShanLoCRomanLoC': 'ái',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
    },
  'Khmery2': {
      'KhmerLoC': 'ឪ',
      'KhmerLoCRomanLoC': 'ýu',
     'OthersRev': [4, '\u02C2'],
     'OthersNonRev': [4, '\u02C2'],
  },
  'Khmery': {
      'KhmerLoC': 'អ\u17B7\u17C6\u02B2',
      'KhmerLoCRomanLoC': 'ẏ',
     'OthersRev': [2, '\u02C2'],
     'OthersNonRev': [2, '\u02C2'],
  },
  'Khmeryy': {
      'KhmerLoC': 'អឺ\u02B2',
      'KhmerLoCRomanLoC': 'ȳ',
      'OthersRev': [3, '\u02C2'],
      'OthersNonRev': [3, '\u02C2'],
  },
  'Khmerua': {
      'KhmerLoC': 'អួ\u02B2',
      'KhmerLoCRomanLoC': 'ua',
      'OthersRev': [4, '\u02C2'],
      'OthersNonRev': [4, '\u02C2'],
  },
  'Khmeroe': {
      'KhmerLoC': 'អើ\u02B2',
      'KhmerLoCRomanLoC': 'oe',
     'OthersRev': [12, '\u02C2'],
     'OthersNonRev': [12, '\u02C2'],
  },
  'Khmeryye': {
      'KhmerLoC': 'អឿ\u02B2',
      'KhmerLoCRomanLoC': 'ẏa',
     'OthersRev': [0, '\u02C2'],
     'OthersNonRev': [0, '\u02C2'],
  },
  'Khmeria': {
      'KhmerLoC': 'អៀ\u02B2',
      'KhmerLoCRomanLoC': 'ia',
     'OthersRev': [0, '\u02C2'],
     'OthersNonRev': [0, '\u02C2'],
  },
  'Khmershortaa': {
      'KhmerLoC': 'អា់\u02B2',
      'KhmerLoCRomanLoC': 'â',
     'OthersRev': [1, '\u02C2'],
     'OthersNonRev': [1, '\u02C2'],
  },
  'Thamcloseda': {
     'ThamLoC': 'ᩋᩢ',
     'TaiTham': 'ᩋᩢ',
     'LaoTham': 'ᩋᩢ',
     'LueTham': 'ᩋᩢ',
     'KhuenTham': 'ᩋᩢ',
     'ThamLoCRomanLoC': 'a\u02BD',
     'OthersRev': [0, '\u02C2'],
     'OthersNonRev': [0, '\u02C2'],
  },
  'Thamclosede': {
   'ThamLoC': 'ᩋ\u1A7Fᨿ',
   'TaiTham': 'ᩋ\u1A7Fᨿ',
   'LueTham': 'ᩋ\u1A7Fᨿ',
   'KhuenTham': 'ᩋ\u1A7Fᨿ',
   'LaoTham': 'ᩋ\u1A7Fᨿ',
    'ThamLoCRomanLoC': 'è',
     'OthersRev': [0, '\u02C2'],
     'OthersNonRev': [0, '\u02C2'],
  },
  'Thamclosedau': {
     'ThamLoC': 'ᩋ\u1A7Fᩅ',
     'TaiTham': 'ᩋ\u1A7Fᩅ',
     'LaoTham': 'ᩋ\u1A7Fᩅ',
     'LueTham': 'ᩋ\u1A7Fᩅ',
     'KhuenTham': 'ᩋ\u1A7Fᩅ',
     'ThamLoCRomanLoC': 'ò\u02BD',
     'OthersRev': [13, '\u02C2'],
     'OthersNonRev': [13, '\u02C2'],
  },
  'Thamopeno2h': {
     'ThamLoC': 'ᩋ\u1A70\u1A6C\u1A61',
     'TaiTham': 'ᩋ\u1A70\u1A6C\u1A61',
     'LueTham': 'ᩋ\u1A70\u1A6C\u1A61',
     'KhuenTham': 'ᩋ\u1A70\u1A6C\u1A61',
     'LaoTham': 'ᩋ\u1A70\u1A6C\u1A61',
      'ThamLoCRomanLoC': 'ǫḥ',
     'OthersRev': [12, '\u02C2'],
     'OthersNonRev': [12, '\u02C2'],
  },
  'Thamclosedo2h': {
     'ThamLoC': 'ᩋᩫ',
     'TaiTham': 'ᩋᩫ',
     'LaoTham': 'ᩋᩫ',
     'LueTham': 'ᩋᩫ',
     'KhuenTham': 'ᩋᩫ',
      'ThamLoCRomanLoC': 'ǫḥ\u02BD',
     'OthersRev': [12, '\u02C2'],
     'OthersNonRev': [12, '\u02C2'],
  },
  'Thamohook': {
     'ThamLoC': 'ᩋᩳ',
     'LaoTham': 'ᩋᩳ',
     'TaiTham': 'ᩋᩳ',
     'LueTham': 'ᩋᩳ',
     'KhuenTham': 'ᩋᩳ',
     'ThamLoCRomanLoC': 'ǫ',
     'OthersRev': [12, '\u02C2'],
     'OthersNonRev': [12, '\u02C2'],
  },
  'Thamohookclosed': {
     'ThamLoC': 'ᩋᩬ',
     'LaoTham': 'ᩋᩬ',
     'TaiTham': 'ᩋᩬ',
     'LueTham': 'ᩋᩬ',
     'KhuenTham': 'ᩋᩬ',
     'ThamLoCRomanLoC': 'ǫ\u02BD',
     'OthersRev': [3, '\u02C2'],
     'OthersNonRev': [3, '\u02C2'],
  },
  'Thamouhookk': {
     'ThamLoC': 'ᩋᩧ',
     'TaiTham': 'ᩋᩧ',
     'LaoTham': 'ᩋᩧ',
     'LueTham': 'ᩋᩧ',
     'KhuenTham': 'ᩋᩧ',
     'ThamLoCRomanLoC': 'ư',
     'OthersRev': [4, '\u02C2'],
     'OthersNonRev': [4, '\u02C2'],
  },
  'Thamuuhook': {
     'ThamLoC': 'ᩋᩨ',
     'TaiTham': 'ᩋᩨ',
     'LaoTham': 'ᩋᩨ',
     'LueTham': 'ᩋᩨ',
     'KhuenTham': 'ᩋᩨ',
      'ThamLoCRomanLoC': 'ư̄',
     'OthersRev': [5, '\u02C2'],
     'OthersNonRev': [5, '\u02C2'],
  },
  'Thamaiy': {
     'ThamLoC': 'ᩋᩱ\u1A7Fᨿ',
     'TaiTham': 'ᩋᩱ\u1A7Fᨿ',
     'LueTham': 'ᩋᩱ\u1A7Fᨿ',
     'KhuenTham': 'ᩋᩱ\u1A7Fᨿ',
     'LaoTham': 'ᩋᩱ\u1A7Fᨿ',
      'ThamLoCRomanLoC': 'aiy\u1A7A',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
  },
  'Thamohohooki': {
     'ThamLoC': 'ᩋᩭ',
     'TaiTham': 'ᩋᩭ',
     'LaoTham': 'ᩋᩭ',
     'LueTham': 'ᩋᩭ',
     'KhuenTham': 'ᩋᩭ',
      'ThamLoCRomanLoC': 'ǫi',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
  },
  'Thameo2': {
     'ThamLoC': 'ᩋ\u1A74\u1A7Fᨿ',
     'TaiTham': 'ᩋ\u1A74\u1A7Fᨿ',
     'LaoTham': 'ᩋ\u1A74\u1A7Fᨿ',
     'LueTham': 'ᩋ\u1A74\u1A7Fᨿ',
     'KhuenTham': 'ᩋ\u1A74\u1A7Fᨿ',
      'ThamLoCRomanLoC': 'eo',
     'OthersRev': [12, '\u02C2'],
     'OthersNonRev': [12, '\u02C2'],
  },
  'Thamohao': {
     'ThamLoC': 'ᩋᩮᩢᩣ',
     'TaiTham': 'ᩋᩮᩢᩣ',
     'LaoTham': 'ᩋᩮᩢᩣ',
     'KhuenTham': 'ᩋᩮᩢᩣ',
     'LueTham': 'ᩋᩮᩢᩣ',
      'ThamLoCRomanLoC': 'ao',
     'OthersRev': [13, '\u02C2'],
     'OthersNonRev': [13, '\u02C2'],
  }
}

VowelSignMap = {
'halfu': {
    'Malayalam': '\u0D41\u0D4D',
    'Devanagari': '\u0956',
    'Sharada': '\U000111CB\U000111B6',
    'Tamil': '\u0BC1\u0BCD',
    'IAST': 'ŭ',
    'ISO': 'ŭ',
    'IPA': 'ʉː',
    'OthersRev': [3, 'ʼ'],
    'OthersNonRev': [3, '\u02C2']
    },
'halfuu': {
    'Malayalam': '\u0D42\u0D4D',
    'Devanagari': '\u0957',
    'Sharada': '\U000111CB\U000111B7',
    'Tamil': '\u0BC2\u0BCD',
    'IAST': 'ŭ\u0304',
    'ISO': 'ŭ\u0304',
    'IPA': 'ʉ',
    'OthersRev': [4, 'ʼ'],
    'OthersNonRev': [4, '\u02C2']
    },
'oe': {
    'Devanagari': '\u093A',
    'Sharada': '\U000111CB',
    'IAST': 'ö',
    'ISO': 'ö',
    'IPA': 'ʉː',
    'OthersRev': [0, 'ʼʼ'],
    'OthersNonRev': [0, '\u02C2']
    },
'oee': {
    'Devanagari': '\u093B',
    'Sharada': '\U000111CB\U000111B3',
    'IAST': 'ȫ',
    'ISO': 'ȫ',
    'IPA': 'ʉː',
    'OthersRev': [0, 'ʼʼʼ'],
    'OthersNonRev': [0, '\u02C2']
    },
'ShanLoCesup': {
        'ShanLoC': 'ဵ',
        'Shan': 'ဵ',
        'ShanLoCRomanLoC': 'e\u02BD',
        'OthersRev': [9, '\u02C2'],
        'OthersNonRev': [9, '\u02C2'],
    },
'ShanLoCui': {
       'ShanLoC': 'ို',
       'Shan': 'ို',
       'ShanLoCRomanLoC': 'ui',
       'OthersRev': [3, '\u02C2'],
       'OthersNonRev': [3, '\u02C2'],
    },
'ShanLoCuui': {
       'ShanLoC': 'ိူ',
       'Shan': 'ိူ',
       'ShanLoCRomanLoC': 'ūi',
       'OthersRev': [4, '\u02C2'],
       'OthersNonRev': [4, '\u02C2'],
    },
'ShanLoCuuiv': {
       'ShanLoC': 'ိူဝ်',
       'Shan': 'ိူဝ်',
       'ShanLoCRomanLoC': 'ūiv',
       'OthersRev': [4, '\u02C2'],
       'OthersNonRev': [4, '\u02C2'],
    },
'ShanLoCaai': {
       'ShanLoC': 'ၢႆ',
       'Shan': 'ၢႆ',
       'ShanLoCRomanLoC': 'āi',
       'OthersRev': [10, '\u02C2'],
       'OthersNonRev': [10, '\u02C2'],
    },
'ShanLoCaoi': {
       'ShanLoC': 'ွႆ',
       'Shan': 'ွႆ',
       'ThamLoC': '\u1A7Fᩅᩭ',
       'ShanLoCRomanLoC': 'oi',
       'ThamLoCRomanLoC': 'oi',
       'OthersRev': [10, '\u02C2'],
       'OthersNonRev': [10, '\u02C2'],
    },
'ShanLoCoalt1': {
       'ShanLoC': 'ေႃ်',
       'Shan': 'ေႃ်',
       'ShanLoCRomanLoC': 'ò',
       'OthersRev': [11, '\u02C2'],
       'OthersNonRev': [11, '\u02C2'],
    },
 'ShanLoCoalt': {
     'ShanLoC': 'ူဝ်',
     'Shan': 'ူဝ်',
     'ShanLoCRomanLoC': 'ō',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
    },
 'ShanLoCaialt': {
     'ShanLoC': '\u036E',
     'Shan': '\u036E',
     'ShanLoCRomanLoC': 'ái',
     'OthersRev': [10, '\u02C2'],
     'OthersNonRev': [10, '\u02C2'],
    },
  'Khmery2': {
      'KhmerLoC': '្ឪ',
      'KhmerLoCRomanLoC': 'ýu',
     'OthersRev': [4, '\u02C2'],
     'OthersNonRev': [4, '\u02C2'],
  },
  'Khmery': {
      'KhmerLoC': '\u17B7\u17C6\u02BD',
      'KhmerLoCRomanLoC': 'ẏ',
     'OthersRev': [1, '\u02C2'],
     'OthersNonRev': [1, '\u02C2'],
  },
  'Khmeryy': {
      'KhmerLoC': 'ឺ',
      'KhmerLoCRomanLoC': 'ȳ',
      'OthersRev': [2, '\u02C2'],
      'OthersNonRev': [2, '\u02C2'],
  },
  'Khmerua': {
      'KhmerLoC': 'ួ',
      'KhmerLoCRomanLoC': 'ua',
      'OthersRev': [3, '\u02C2'],
      'OthersNonRev': [3, '\u02C2'],
  },
  'Khmeroe': {
      'KhmerLoC': 'ើ',
      'KhmerLoCRomanLoC': 'oe',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
  },
  'Khmeryye': {
      'KhmerLoC': 'ឿ',
      'KhmerLoCRomanLoC': 'ẏa',
     'OthersRev': [-1, '\u02C2'],
     'OthersNonRev': [-1, '\u02C2'],
  },
  'Khmeria': {
      'KhmerLoC': 'ៀ',
      'KhmerLoCRomanLoC': 'ia',
     'OthersRev': [-1, '\u02C2'],
     'OthersNonRev': [-1, '\u02C2'],
  },
  'Khmershortaa': {
      'KhmerLoC': 'ា់',
      'KhmerLoCRomanLoC': 'â',
     'OthersRev': [0, '\u02C2'],
     'OthersNonRev': [0, '\u02C2'],
  },
  'Thamcloseda': {
      'ThamLoC': 'ᩢ',
      'TaiTham': 'ᩢ',
      'LaoTham': 'ᩢ',
      'KhuenTham': 'ᩢ',
      'LueTham': 'ᩢ',
      'ThamLoCRomanLoC': 'a\u02BD',
     'OthersRev': [-1, '\u02C2'],
     'OthersNonRev': [-1, '\u02C2'],
  },
  'Thamclosede': {
    'ThamLoC': '\u1A7Fᨿ',
    'TaiTham': '\u1A7Fᨿ',
    'LaoTham': '\u1A7Fᨿ',
    'KhuenTham': '\u1A7Fᨿ',
    'LueTham': '\u1A7Fᨿ',
    'ThamLoCRomanLoC': 'è',
     'OthersRev': [9, '\u02C2'],
     'OthersNonRev': [9, '\u02C2'],
  },
  'Thamclosedau': {
      'ThamLoC': '\u1A7Fᩅ',
      'TaiTham': '\u1A7Fᩅ',
      'LaoTham': '\u1A7Fᩅ',
      'LueTham': '\u1A7Fᩅ',
      'KhuenTham': '\u1A7Fᩅ',
      'ThamLoCRomanLoC': 'ò\u02BD',
     'OthersRev': [13, '\u02C2'],
     'OthersNonRev': [13, '\u02C2'],
  },
  'Thamopeno2h': {
      'ThamLoC': '\u1A70\u1A6C\u1A61',
      'TaiTham': '\u1A70\u1A6C\u1A61',
      'LaoTham': '\u1A70\u1A6C\u1A61',
      'LueTham': '\u1A70\u1A6C\u1A61',
      'KhuenTham': '\u1A70\u1A6C\u1A61',
      'ThamLoCRomanLoC': 'ǫḥ',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
  },
  'Thamclosedo2h': {
      'ThamLoC': 'ᩫ',
      'TaiTham': 'ᩳ',
      'LaoTham': 'ᩳ',
      'KhuenTham': 'ᩳ',
      'LueTham': 'ᩳ',

      'ThamLoCRomanLoC': 'ǫḥ\u02BD',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
  },
  'Thamohook': {
      'ThamLoC': 'ᩳ',
      'ThamLoCRomanLoC': 'ǫ',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
  },
  'Thamohookclosed': {
      'ThamLoC': 'ᩬ',
      'TaiTham': 'ᩬ',
      'LaoTham': 'ᩬ',
      'KhuenTham': 'ᩬ',
      'LueTham': 'ᩬ',
      'ThamLoCRomanLoC': 'ǫ\u02BD',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
  },
  'Thamouhookk': {
      'ThamLoC': 'ᩧ',
      'TaiTham': 'ᩧ',
      'LaoTham': 'ᩧ',
      'KhuenTham': 'ᩧ',
      'LueTham': 'ᩧ',
      'ThamLoCRomanLoC': 'ư',
     'OthersRev': [3, '\u02C2'],
     'OthersNonRev': [3, '\u02C2'],
  },
  'Thamuuhook': {
      'ThamLoC': 'ᩨ',
      'TaiTham': 'ᩨ',
      'LaoTham': 'ᩨ',
      'KhuenTham': 'ᩨ',
      'LueTham': 'ᩨ',
      'ThamLoCRomanLoC': 'ư̄',
     'OthersRev': [4, '\u02C2'],
     'OthersNonRev': [4, '\u02C2'],
  },
  'Thamaiy': {
      'ThamLoC': 'ᩱ\u1A7Fᨿ',
      'TaiTham': 'ᩱ\u1A7Fᨿ',
      'LaoTham': 'ᩱ\u1A7Fᨿ',
      'KhuenTham': 'ᩱ\u1A7Fᨿ',
      'LueTham': 'ᩱ\u1A7Fᨿ',
      'ThamLoCRomanLoC': 'aiy\u1A7A',
     'OthersRev': [10, '\u02C2'],
     'OthersNonRev': [10, '\u02C2'],
  },
  'Thamohohooki': {
      'ThamLoC': 'ᩭ',
      'TaiTham': 'ᩭ',
      'LaoTham': 'ᩭ',
      'KhuenTham': 'ᩭ',
      'LueTham': 'ᩭ',
      'ThamLoCRomanLoC': 'ǫi',
     'OthersRev': [10, '\u02C2'],
     'OthersNonRev': [10, '\u02C2'],
  },
  'Thameo2': {
      'ThamLoC': '\u1A74\u1A7Fᨿ',
      'TaiTham': '\u1A74\u1A7Fᨿ',
      'LueTham': '\u1A74\u1A7Fᨿ',
      'KhuenTham': '\u1A74\u1A7Fᨿ',
      'LaoTham': '\u1A74\u1A7Fᨿ',
      'ThamLoCRomanLoC': 'eo',
     'OthersRev': [11, '\u02C2'],
     'OthersNonRev': [11, '\u02C2'],
  },
  'Thamohao': {
      'ThamLoC': 'ᩮᩢᩣ',
      'Tham': 'ᩮᩢᩣ',
      'ThamLoCRomanLoC': 'ao',
     'OthersRev': [12, '\u02C2'],
     'OthersNonRev': [12, '\u02C2'],
  }
}

ModernVowelSignMap = {
'ShanLoCeaeup': {
        'ShanLoC': 'ႅ',
        'Shan': 'ႅ',
        'ShanLoCRomanLoC': 'è\u02BD',
        'OthersRev': [0, '\u02C2'],
        'OthersNonRev': [0, '\u02C2'],
    },
'ShanLoCeae2': {
        'ShanLoC': 'ေေ',
        'Shan': 'ေေ',
        'ShanLoCRomanLoC': 'è\u02BD',
        'OthersRev': [0, '\u02C2'],
        'OthersNonRev': [0, '\u02C2'],
    },
  'Thamhoe': {
      'ThamLoC': 'ᩮᩨᩬ',
      'TaiTham': 'ᩮᩨᩬ',
      'LaoTham': 'ᩮᩨᩬ',
      'KhuenTham': 'ᩮᩨᩬ',
      'LueTham': 'ᩮᩨᩬ',
      'ThamLoCRomanLoC': 'œ',
     'OthersRev': [1, '\u02C2'],
     'OthersNonRev': [1, '\u02C2'],
  },
  'Thamoeclosed': {
      'ThamLoC': 'ᩮᩨ',
      'TaiTham': 'ᩮᩨ',
      'LaoTham': 'ᩮᩨ',
      'KhuenTham': 'ᩮᩨ',
      'LueTham': 'ᩮᩨ',
      'ThamLoCRomanLoC': 'œ\u02BD',
     'OthersRev': [1, '\u02C2'],
     'OthersNonRev': [1, '\u02C2'],
  }
}

ModernVowelMap = {
'ShanLoCeaeup': {
        'ShanLoC': 'ဢႅ',
        'Shan': 'ဢႅ',
        'ShanLoCRomanLoC': 'è',
        'OthersRev': [0, '\u02C2'],
        'OthersNonRev': [0, '\u02C2'],
    },
'ShanLoCeae2': {
        'ShanLoC': 'ဢေေ',
        'Shan': 'ဢေေ',
        'ShanLoCRomanLoC': 'è',
        'OthersRev': [0, '\u02C2'],
        'OthersNonRev': [0, '\u02C2'],
    },
  'Thamhoe': {
     'ThamLoC': 'ᩋᩮᩨᩬ',
     'TaiTham': 'ᩋᩮᩨᩬ',
     'LaoTham': 'ᩋᩮᩨᩬ',
     'LueTham': 'ᩋᩮᩨᩬ',
     'KhuenTham': 'ᩋᩮᩨᩬ',
      'ThamLoCRomanLoC': 'œ',
     'OthersRev': [1, '\u02C2'],
     'OthersNonRev': [1, '\u02C2'],
  },
  'Thamoeclosed': {
     'ThamLoC': 'ᩋᩮᩨ',
     'TaiTham': 'ᩋᩮᩨ',
     'LaoTham': 'ᩋᩮᩨ',
     'LueTham': 'ᩋᩮᩨ',
     'KhuenTham': 'ᩋᩮᩨ',
      'ThamLoCRomanLoC': 'œ\u02BD',
     'OthersRev': [1, '\u02C2'],
     'OthersNonRev': [1, '\u02C2'],
  }
}

ConsonantMap = {
'theta': {
        'ShanLoC': 'ႀ',
        'Shan': 'ႀ',
        'ShanLoCRomanLoC': 'x',
        'OthersRev': [15, 'nukta'],
        'OthersNonRev': [15, 'nukta'],
    },
 'khmernga': {
     'KhmerLoC' : 'ង៉',
     'KhmerLoCRomanLoC': 'ṅ″',
     'OthersRev': [4, '\u02C2'],
     'OthersNonRev': [4, '\u02C2'],
 },
 'khmernja': {
     'KhmerLoC' : 'ញ៉',
     'KhmerLoCRomanLoC': 'ñ″',
     'OthersRev': [9, '\u02C2'],
     'OthersNonRev': [9, '\u02C2'],
 },
 'khmerma': {
     'KhmerLoC' : 'ម៉',
     'KhmerLoCRomanLoC': 'm″',
     'OthersRev': [24, '\u02C2'],
     'OthersNonRev': [24, '\u02C2'],
 },
 'khmerpa': {
     'KhmerLoC' : 'ប៉',
     'KhmerLoCRomanLoC': 'p″',
     'OthersRev': [20, '\u02C2'],
     'OthersNonRev': [20, '\u02C2'],
 },
 'khmerya': {
     'KhmerLoC' : 'យ៉',
     'KhmerLoCRomanLoC': 'y″',
     'OthersRev': [25, '\u02C2'],
     'OthersNonRev': [25, '\u02C2'],
 },
 'khmerra': {
     'KhmerLoC' : 'រ៉',
     'KhmerLoCRomanLoC': 'r″',
     'OthersRev': [26, '\u02C2'],
     'OthersNonRev': [26, '\u02C2'],
 },
 'khmerva': {
     'KhmerLoC' : 'វ៉',
     'KhmerLoCRomanLoC': 'v″',
     'OthersRev': [28, '\u02C2'],
     'OthersNonRev': [28, '\u02C2'],
 },
 'khmerpa2': {
     'KhmerLoC' : 'ប៊',
     'KhmerLoCRomanLoC': 'p′',
     'OthersRev': [20, '\u02C2'],
     'OthersNonRev': [20, '\u02C2'],
 },
 'khmersa': {
     'KhmerLoC' : 'ស៊',
     'KhmerLoCRomanLoC': 's′',
     'OthersRev': [31, '\u02C2'],
     'OthersNonRev': [31, '\u02C2'],
 },
 'khmerha': {
     'Khmer' : 'ហ៊',
     'KhmerLoC' : 'ហ៊',
     'KhmerLoCRomanLoC': 'h′',
     'OthersRev': [32, '\u02C2'],
     'OthersNonRev': [32, '\u02C2'],
 },
 'khmeracons': {
     'KhmerLoC' : 'អ',
     'KhmerLoCRomanLoC': '‛ʹ',
     'OthersRev': [0, '\u02C2'],
     'OthersNonRev': [0, '\u02C2'],
 },
 'khmeraconsmod': {
     'KhmerLoC' : 'អ៊',
     'KhmerLoCRomanLoC': '‛ʹ′',
     'OthersRev': [0, '\u02C2'],
     'OthersNonRev': [0, '\u02C2'],
 },
 'ThamDoubleNJNJ': {
     'ThamLoC' : 'ᨬᩚ',
     'ThamLoCRomanLoC': 'ññ',
     'OthersRev': [9, '\u02C2'],
     'OthersNonRev': [9, '\u02C2'],
 },

}

SignMap = {
    'shanexcl' : {
        'ShanLoC': '႟',
        'Shan': '႟',
        'ShanLoCRomanLoC': 'u*',
        'OthersRev': [-1, '!\u02C2\u02C2\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '!\u02C2\u02C2\u02C2\u02C2'],
    },
    'shanone' : {
        'ShanLoC': '႞',
        'Shan': '႞',
        'ShanLoCRomanLoC': 'n*',
        'OthersRev': [-1, '!!\u02C2'],
        'OthersNonRev': [-1, '!!\u02C2'],
    },
    'Khmerdivider' : {
      'KhmerLoC': '៖',
      'KhmerLoCRomanLoC': ':',
     'OthersRev': [-1, '!!!\u02C2'],
     'OthersNonRev': [-1, '!!!\u02C2'],
    },
    'Thamlae': {
        'ThamLoC': 'ᩓ',
        'ThamLoCRomanLoC': 'læ',
        'OthersRev': [-1, '!!!\u02C2'],
        'OthersNonRev': [-1, '!!!\u02C2'],
    },
    """'Danda1': {
        'Devanagari': '│',
        'OthersRev': [1, '\u02C2'],
        'OthersNonRev': [1, '\u02C2'],
    },
    'Danda2': {
        'Devanagari': '┃',
        'OthersRev': [2, '\u02C2'],
        'OthersNonRev': [2, '\u02C2'],
    },"""
    'Thamlae': {
        'ThamLoC': 'ᩓ',
        'ThamLoCRomanLoC': 'læ',
        'OthersRev': [-1, '!!!\u02C2'],
        'OthersNonRev': [-1, '!!!\u02C2'],
    }
}

AyogavahaMap = {
'Jihvamuliya': {
    'IAST': 'ẖ',
    'ISO': 'ẖ',
    'IASTPali': 'ẖ',
    'Titus': 'ẖ',
    'HK': 'X',
    'Itrans': 'X',
    'Devanagari': '\u1CF5',
    'Bengali': '\u1CF5',
    'Assamese': '\u1CF5',
    'Kannada': '\u0CF1',
    'Tibetan': '\u0F88',
    'Brahmi': '\U00011003',
    'Sharada': '\U000111C2',
    'Newa': '\U00011460',
    'Soyombo': '\U00011A84',
    'OthersRev': [2, '\u02C2'],
    'OthersNonRev': [2, '\u02C2']
    },
'Upadhmaniya': {
    'IAST': 'ḫ',
    'ISO': 'ḫ',
    'IASTPali': 'ḫ',
    'Titus': 'ḫ',
    'HK': 'F',
    'Itrans': 'F',
    'Devanagari': '\u1CF6',
    'Bengali': '\u1CF6',
    'Assamese': '\u1CF6',
    'Kannada': '\u0CF2',
    'Tibetan': '\u0F89',
    'Brahmi': '\U00011004',
    'Sharada': '\U000111C3',
    'Newa': '\U00011461',
    'Soyombo': '\U00011A85',
    'OthersRev': [2, '\u02C2'],
    'OthersNonRev': [2, '\u02C2']
    },
    'shantone2' : {
        'ShanLoC': 'ႇ',
        'Shan': 'ႇ',
        'ShanLoCRomanLoC': '\u0322',
        'OthersRev': [-1, '\u02C2'],
        'OthersNonRev': [-1, '\u02C2'],
    },
    'shantone3' : {
        'ShanLoC': 'ႈ',
        'Shan': 'ႈ',
        'ShanLoCRomanLoC': '\u0310',
        'OthersRev': [-1, '\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2'],
    },
    'shantone5' : {
        'ShanLoC': 'ႉ',
        'Shan': 'ႉ',
        'ShanLoCRomanLoC': 'ʹ',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2'],
    },
    'shantone6' : {
        'ShanLoC': 'ႊ',
        'Shan': 'ႊ',
        'ShanLoCRomanLoC': '˝',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2\u02C2'],
    },
    'KhmerTone3' : {
        'KhmerLoC': '៍',
        'KhmerLoCRomanLoC': '\u02DA',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2'],
    },
    'KhmerTone4' : {
        'KhmerLoC': '៎',
        'KhmerLoCRomanLoC': '’',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2'],
    },
    'KhmerTone5' : {
        'KhmerLoC': '៏',
        'KhmerLoCRomanLoC': 'ʻ',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2'],
    },
  'Khmerbreve': {
      'KhmerLoC': '័',
      'KhmerLoCRomanLoC': '\u0306',
     'OthersRev': [-1, '\u02C2'],
     'OthersNonRev': [-1, '\u02C2'],
  },
  'Khmervisarga2': {
      'KhmerLoC': 'ៈ',
      'KhmerLoCRomanLoC': '\u0300',
     'OthersRev': [-1, '\u02C2'],
     'OthersNonRev': [-1, '\u02C2'],
  },
  'Khmershortener': {
      'KhmerLoC': '់',
      'KhmerLoCRomanLoC': '\u0301',
     'OthersRev': [-1, '\u02C2'],
     'OthersNonRev': [-1, '\u02C2'],
  },
    'ThamTone1': {
        'ThamLoC': '᩵',
        'TaiTham': '᩵',
        'LaoTham': '᩵',
        'LueTham': '᩵',
        'KhuenTham': '᩵',
        'ThamLoCRomanLoC': '\u2032',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
    },
    'ThamTone2': {
        'ThamLoC': '᩶',
        'TaiTham': '᩶',
        'LaoTham': '᩶',
        'LueTham': '᩶',
        'KhuenTham': '᩶',
        'ThamLoCRomanLoC': '\u2033',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
    },
    'ThamTone3': {
        'ThamLoC': '᩷',
        'TaiTham': '᩷',
        'LaoTham': '᩷',
        'LueTham': '᩷',
        'KhuenTham': '᩷',
        'ThamLoCRomanLoC': 'ˆ',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
    },
    'ThamTone4': {
        'ThamLoC': '᩸',
        'TaiTham': '᩸',
        'LaoTham': '᩸',
        'LueTham': '᩸',
        'KhuenTham': '᩸',
        'ThamLoCRomanLoC': 'ᴶ',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
    },
    'ThamTone5': {
        'ThamLoC': '᩹',
        'TaiTham': '᩹',
        'LaoTham': '᩹',
        'LueTham': '᩹',
        'KhuenTham': '᩹',
        'ThamLoCRomanLoC': 'ʵ',
        'OthersRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
        'OthersNonRev': [-1, '\u02C2\u02C2\u02C2\u02C2\u02C2'],
    }
}